แพ็คเกจนี้เป็นแพ็คเกจ python ที่แสดงข้อมูลเกี่ยวกับแมวตัวนึง”
=============================================================

PyPi: https://pypi.org/project/paotung/

สวัสดี นี่คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับแมวตัวนึง

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install paotung

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from paotung import Paotung

   paotung = Paotung() # ประกาศชื่อคลาส
   paotung.show_name() # โชว์ชื่อ
   paotung.show_web() # โชว์เว็บ
   paotung.about() # โชว์เกี่ยวกับเป๋าตุง
   paotung.show_art() # โชว์ภาพศิลปะ

พัฒนาโดย: FB: https://www.facebook.com/patcharaporn.saguan
